# Caddy Module: Websocket/Telnet Proxy

TelnetProxy is a [Caddy](https://caddyserver.com) module that proxies WebSocket connections to Telnet servers. This module allows clients to securely connect via WebSockets and interact with Telnet servers, making it easier to expose legacy Telnet services over modern web protocols.

## Features

- **WebSocket to Telnet Proxy:** Forwards WebSocket connections to Telnet servers.
- **Authentication:** Uses a shared secret to authenticate incoming WebSocket connections.
- **Caddy Integration:** Easily integrated with Caddy via the Caddyfile.
- **Timeout Handling:** Includes dial and inactivity timeouts for more robust connections.
- **Modular & Extendable:** Built as a Caddy module for easy inclusion in custom Caddy builds.

## Requirements

- [Caddy v2](https://caddyserver.com/docs/v2)
- [Go](https://golang.org/) (version 1.16 or later is recommended)
- [Gorilla WebSocket](https://github.com/gorilla/websocket)

## Installation

There are two primary ways to use TelnetProxy with Caddy:

### 1. Build as a Plugin for Caddy

Clone this repository and follow [Caddy's custom build instructions](https://caddyserver.com/docs/extending-caddy) to include the module in your Caddy binary.

```bash
git clone https://github.com/yourusername/telnetproxy.git
cd telnetproxy
go build ./...



[GAIA](https://aistudio.google.com/app/prompts?state=%7B%22ids%22:%5B%221TZojNHHHimN35L0xxFXjHtuUVjufmy8q%22%5D,%22action%22:%22open%22,%22userId%22:%22100999063508256084521%22,%22resourceKeys%22:%7B%7D%7D&usp=sharing)

## Client
- https://ryanmalloy.com/telnet/
  - xterm.js
  - HTML/CSS

## Killer UIX
- [AmberCRT](https://ryanmalloy.com/amber-crt/)
  - Reminiscent of a "Amber Monochrome/Hercules Adaptor"
  - Packard Bell cause my first VGA monitor was one

## Commercial Products
- https://www.ftelnet.ca/download/

